meteolib
========
This module conatins standard equations, constants and conversions
for general use in meteorology.
Values and methods herin are are either adopted or recommended 
by the World meteorological Organization (WMO) and similar bodies 
or backed by peer-reviewed literature and fully citable.

Note
=========
This module is in a stub state until publication of the corresponding paper

